from typer import Typer, Argument
from typing_extensions import Annotated
from pathlib import Path

from imagetools.cli.apply import apply_configuration
from imagetools.cli.flask import flask
from imagetools.lib.exif import get_date, has_date
from imagetools.lib.filesystem import filter_ls, scramble, sequential_rename

app = Typer()


@app.command()
def rename(
    directories: Annotated[list[Path], Argument(help="The directories to rename", dir_okay=True, exists=True, writable=True, resolve_path=True)],
) -> None:
    for directory in directories:
        scramble(directory)

        files = filter_ls(directory, has_date, get_date)

        sequential_rename(files)


@app.command()
def date(
    configuration: Annotated[Path, Argument(help="Path of configuration file to edit", file_okay=True, exists=False, writable=True, resolve_path=True)],
    directories: Annotated[
        list[Path], Argument(help="The directories to scan for undated files", dir_okay=True, exists=True, readable=True, resolve_path=True)
    ],
) -> None:
    flask.config["CORS_HEADERS"] = "Content-Type"
    flask.config["filter_file"] = configuration
    flask.config["base_folders"] = directories

    flask.run(debug=True)


@app.command()
def apply(
    configuration: Annotated[Path, Argument(help="Path of configuration file to apply", file_okay=True, exists=True, readable=True, resolve_path=True)],
    directories: Annotated[
        list[Path], Argument(help="The directories to apply changes to", dir_okay=True, exists=True, writable=True, resolve_path=True)
    ],
) -> None:
    apply_configuration(configuration)


if __name__ == "__main__":
    app()
